pub struct RoutingContext<'a> { /* private fields */ }Expand description
Routing metadata shared by source and sink records.
Implementations
Sourceimpl<'a> RoutingContext<'a>
impl<'a> RoutingContext<'a>
Sourcepub fn new(
topic: &'a str,
key: Option<&'a str>,
partition: Option<&'a str>,
attributes: &'a HashMap<String, String>,
) -> Self
pub fn new( topic: &'a str, key: Option<&'a str>, partition: Option<&'a str>, attributes: &'a HashMap<String, String>, ) -> Self
Create a routing context from its raw topic, key, partition, and attributes.
Sourcepub fn key(&self) -> Option<&'a str>
pub fn key(&self) -> Option<&'a str>
Return the routing key used for partitioned publishing, if present.
Sourcepub fn partition(&self) -> Option<&'a str>
pub fn partition(&self) -> Option<&'a str>
Return the partition identifier for consumed records, if known.
Sourcepub fn attributes(&self) -> &'a HashMap<String, String>
pub fn attributes(&self) -> &'a HashMap<String, String>
Return the user-defined record attributes.