pub struct SourceSender { /* private fields */ }Expand description
Handle used by streaming connectors to emit records into the runtime.
This struct provides methods to send records to the runtime for publishing.
Implementations
Sourceimpl SourceSender
impl SourceSender
Sourcepub async fn send(
&self,
envelope: impl Into<SourceEnvelope>,
) -> ConnectorResult<()>
pub async fn send( &self, envelope: impl Into<SourceEnvelope>, ) -> ConnectorResult<()>
Send a single record envelope to the runtime.
This method is used by streaming connectors to emit records as they become available.
Sourcepub async fn send_batch<I>(&self, envelopes: I) -> ConnectorResult<()>
pub async fn send_batch<I>(&self, envelopes: I) -> ConnectorResult<()>
Send multiple record envelopes to the runtime in sequence.
This method is used by streaming connectors to emit multiple records at once.